@@ -104,6 +104,15 @@ matching_l1 <- function(w,
   if (!optimized_compile){
     return(dp)
   } else {
-    return(dp["row_index"])
+    row_index <- NULL
+    row_index_data <- dp["row_index"]
+    row.names(row_index_data) <- NULL
+    data.table::setDT(row_index_data)
+    freq_table <- row_index_data[ , .N, by=row_index]
+    freq_table <- freq_table[order(row_index)]
+    row.names(freq_table) <- NULL
+    row_index_data <- NULL
+
+    return(freq_table)
   }
 }
